@@ -5,7 +5,7 @@ from tensorflow.keras.layers import (Conv2D, Dense, BatchNormalization,
                                      GlobalAveragePooling2D, Dropout,
                                      Multiply, Add, ReLU, Reshape)
 
-from efficient_det.utils.model_service import round_filters, round_repeats
+from efficient_det.utils.scale_model import round_filters, round_repeats
 
 
 def mb_conv_block(x_in, in_channel, squeeze, kernel_size, strides,
