@@ -4,7 +4,7 @@ import ray
 from ray import tune
 
 from efficient_det.utils.parser import parse_args
-from hyper_parameter_search import hyper_param_search
+from efficient_det.hyper_parameter_search import hyper_param_search
 
 
 def main(args=None):
@@ -28,5 +28,5 @@ def main(args=None):
 
 
 if __name__ == '__main__':
-    os.environ['WANDB_API_KEY'] = '222942f43da8052ed402db5efa33e0ec0f9a14bd'
+    os.environ['WANDB_API_KEY'] = ''
     main()
