@@ -50,7 +50,7 @@ def parse_annotations(xml_file, annotations_path, names_to_labels):
     Args:
         xml_file: Name of xml file.
         annotations_path: Path to annotations.
-        names_to_labels:
+        names_to_labels: Dictionary mapping name to label id.
 
     Returns: Boxes and corresponding labels in an image.
 
